@@ -2,7 +2,6 @@ import os.path as op
 
 import h5py
 import numpy as np
-import pandas
 import pandas as pd
 import pytest
 import scipy.sparse as sps
@@ -41,14 +40,14 @@ def test_bintable_many_contigs():
     # so chromosome names are taken from the chroms/name
     clr = api.Cooler(op.join(datadir, "manycontigs.1.cool"))
     bins = clr.bins()[:10]
-    assert pd.api.types.is_categorical_dtype(bins["chrom"].dtype)
+    assert isinstance(bins["chrom"].dtype, pd.CategoricalDtype)
 
-    bins = clr.bins()[['chrom', 'start']][:10]
-    assert pd.api.types.is_categorical_dtype(bins["chrom"].dtype)
+    bins = clr.bins()[["chrom", "start"]][:10]
+    assert isinstance(bins["chrom"].dtype, pd.CategoricalDtype)
 
-    chroms = clr.bins()['chrom'][:10]
-    clr.bins()['start'][:10]
-    assert pd.api.types.is_categorical_dtype(chroms.dtype)
+    chroms = clr.bins()["chrom"][:10]
+    clr.bins()["start"][:10]
+    assert isinstance(chroms.dtype, pd.CategoricalDtype)
 
 
 def test_pixeltable(mock_cooler):
@@ -96,10 +95,32 @@ def test_annotate_with_partial_bins():
 
     out = api.annotate(pix, bins_chr2)
 
-    for col in ['chrom1', 'start1', 'end1', 'chrom2', 'start2', 'end2']:
+    for col in ["chrom1", "start1", "end1", "chrom2", "start2", "end2"]:
         assert out[col].notnull().all()
 
 
+def test_annotate_with_partial_bins_and_partial_pixels():
+    # Addresses a bug where annotating only certain pixels with a partial
+    # bin-table dataframe would lead to IndexError
+
+    clr = api.Cooler(op.join(datadir, "hg19.GM12878-MboI.matrix.2000kb.cool"))
+    region = "chr2:0-1000000"
+
+    pix = clr.matrix(as_pixels=True, balance=False).fetch(region)
+
+    # Use partial bin table
+    bins_region = clr.bins().fetch(region)
+    out = api.annotate(pix, bins_region)
+    for col in ["chrom1", "start1", "end1", "chrom2", "start2", "end2"]:
+        assert out[col].notnull().all()
+
+    # Compare with full bin table as selector
+    pd.testing.assert_frame_equal(out, api.annotate(pix, clr.bins()))
+
+    # Compare with full bin table materialized
+    pd.testing.assert_frame_equal(out, api.annotate(pix, clr.bins()[:]))
+
+
 def test_matrix():
     clr = api.Cooler(op.join(datadir, "yeast.10kb.cool"))
     region = ("chrI:100345-220254", "chrII:200789-813183")
@@ -112,9 +133,7 @@ def test_matrix():
     clr.matrix(sparse=True, balance=False).fetch(*region)
     clr.matrix(sparse=True, balance=True).fetch(*region)
     clr.matrix(sparse=True, balance="weight").fetch(*region)
-    clr.matrix(
-        sparse=True, balance="weight", divisive_weights=True
-    ).fetch(*region)
+    clr.matrix(sparse=True, balance="weight", divisive_weights=True).fetch(*region)
     # dataframe
     clr.matrix(as_pixels=True, join=False, balance=False).fetch(*region)
     clr.matrix(as_pixels=True, join=False, balance=True).fetch(*region)
@@ -150,10 +169,7 @@ def test_cooler_class(mock_cooler):
 
     # chrom table
     table = clr.chroms()[:]
-    assert (
-        table["name"].tolist()
-        == mock_cooler["chroms"]["name"].astype('U').tolist()
-    )
+    assert table["name"].tolist() == mock_cooler["chroms"]["name"].astype("U").tolist()
     assert np.all(table["length"] == mock_cooler["chroms"]["length"])
 
     # bin table
@@ -180,29 +196,29 @@ def test_cooler_class(mock_cooler):
 
 def test_cooler_class2():
     path = op.join(datadir, "toy.symm.upper.2.cool")
-    with h5py.File(path, 'r') as f:
+    with h5py.File(path, "r") as f:
         clr = api.Cooler(f)
         repr(clr)
-        assert clr.root == '/'
+        assert clr.root == "/"
         assert clr.filename == path
         assert isinstance(clr.store, h5py.File)
-        with clr.open('r') as f:
+        with clr.open("r") as f:
             pass
 
     with pytest.raises(KeyError):
-        api.Cooler(path + '::/does/not/exist')
+        api.Cooler(path + "::/does/not/exist")
 
     clr = api.Cooler(path)
-    clr._load_dset('indexes/chrom_offset')
-    clr._load_dset('indexes/bin1_offset')
-    clr._load_attrs('bins/chrom')
+    clr._load_dset("indexes/chrom_offset")
+    clr._load_dset("indexes/bin1_offset")
+    clr._load_attrs("bins/chrom")
 
-    with clr.open('r') as f:
+    with clr.open("r") as f:
         pass
 
-    assert clr.storage_mode == 'symmetric-upper'
+    assert clr.storage_mode == "symmetric-upper"
     assert clr.binsize == 2
     assert len(clr.chromsizes) == 2
-    assert clr.info['nchroms'] == 2
-    assert clr.chromnames == ['chr1', 'chr2']
-    assert repr(clr) == '<Cooler "{}::{}">'.format('toy.symm.upper.2.cool', '/')
+    assert clr.info["nchroms"] == 2
+    assert clr.chromnames == ["chr1", "chr2"]
+    assert repr(clr) == '<Cooler "{}::{}">'.format("toy.symm.upper.2.cool", "/")
