@@ -14,114 +14,104 @@ from cooler.core._selectors import _IndexingMixin
 def make_hdf5_table(mode):
     s = BytesIO()
     f = h5py.File(s, mode)
-    h5opts = dict(compression='gzip', compression_opts=6, maxshape=(None,))
-    grp = f.create_group('table')
+    h5opts = dict(compression="gzip", compression_opts=6, maxshape=(None,))
+    grp = f.create_group("table")
     grp.create_dataset(
-        'chrom',
-        data=np.array(['chr1', 'chr1', 'chr1', 'chr2', 'chr2'], dtype='S'),
-        **h5opts
-    )
-    grp.create_dataset(
-        'start',
-        data=[0, 10, 20, 0, 10],
-        **h5opts
-    )
-    grp.create_dataset(
-        'end',
-        data=[10, 20, 32, 10, 21],
-        **h5opts
-    )
-    grp.create_dataset(
-        'value',
-        data=[1.1, 2.0, 3.0, 4.0, 5.0],
-        **h5opts
+        "chrom",
+        data=np.array(["chr1", "chr1", "chr1", "chr2", "chr2"], dtype="S"),
+        **h5opts,
     )
+    grp.create_dataset("start", data=[0, 10, 20, 0, 10], **h5opts)
+    grp.create_dataset("end", data=[10, 20, 32, 10, 21], **h5opts)
+    grp.create_dataset("value", data=[1.1, 2.0, 3.0, 4.0, 5.0], **h5opts)
     f.flush()
     return f
 
 
 def test_get():
-    f = make_hdf5_table('a')
-    out = core.get(f['table'], 0, 3, ['chrom', 'value'])
+    f = make_hdf5_table("a")
+    out = core.get(f["table"], 0, 3, ["chrom", "value"])
     assert isinstance(out, pd.DataFrame)
     assert len(out.columns) == 2
-    assert out['chrom'].astype('U').tolist() == ['chr1', 'chr1', 'chr1']
-    assert np.allclose(out['value'].values, [1.1, 2.0, 3.0])
+    assert out["chrom"].astype("U").tolist() == ["chr1", "chr1", "chr1"]
+    assert np.allclose(out["value"].values, [1.1, 2.0, 3.0])
 
-    out = core.get(f['table'], 0, 3, 'value')
+    out = core.get(f["table"], 0, 3, "value")
     assert isinstance(out, pd.Series)
     assert np.allclose(out.values, [1.1, 2.0, 3.0])
 
-    out = core.get(f['table'], 0, 3, 'value', as_dict=True)
+    out = core.get(f["table"], 0, 3, "value", as_dict=True)
     assert isinstance(out, dict)
-    assert np.allclose(out['value'], [1.1, 2.0, 3.0])
+    assert np.allclose(out["value"], [1.1, 2.0, 3.0])
 
-    out = core.get(f['table'])
+    out = core.get(f["table"])
     assert len(out) == 5
     assert len(out.columns) == 4
 
-    out = core.get(f['table'], lo=None)
+    out = core.get(f["table"], lo=None)
     assert len(out) == 5
     assert len(out.columns) == 4
 
-    out = core.get(f['table'], lo=3)
+    out = core.get(f["table"], lo=3)
     assert len(out) == 2
     assert len(out.columns) == 4
 
 
 def test_put():
-    f = make_hdf5_table('a')
+    f = make_hdf5_table("a")
 
     # append
-    df = pd.DataFrame({
-        'chrom': ['chr3', 'chr3'],
-        'start': [0, 20],
-        'end': [20, 40],
-        'value': [4.0, 5.0],
-    })
-    core.put(f['table'], df, lo=5)
+    df = pd.DataFrame(
+        {
+            "chrom": ["chr3", "chr3"],
+            "start": [0, 20],
+            "end": [20, 40],
+            "value": [4.0, 5.0],
+        }
+    )
+    core.put(f["table"], df, lo=5)
     f.flush()
-    out = core.get(f['table'])
+    out = core.get(f["table"])
     assert len(out) == 7
 
     # insert a categorical column
-    s = pd.Series(pd.Categorical(out['chrom'], ordered=True), index=out.index)
-    s.name = 'chrom_enum'
-    core.put(f['table'], s)
-    assert h5py.check_dtype(enum=f['table/chrom_enum'].dtype)
-    out = core.get(f['table'])
+    s = pd.Series(pd.Categorical(out["chrom"], ordered=True), index=out.index)
+    s.name = "chrom_enum"
+    core.put(f["table"], s)
+    assert h5py.check_dtype(enum=f["table/chrom_enum"].dtype)
+    out = core.get(f["table"])
     assert len(out.columns) == 5
-    assert pd.api.types.is_categorical_dtype(out['chrom_enum'].dtype)
-    out = core.get(f['table'], convert_enum=False)
+    assert isinstance(out["chrom_enum"].dtype, pd.CategoricalDtype)
+    out = core.get(f["table"], convert_enum=False)
     assert len(out.columns) == 5
-    assert pd.api.types.is_integer_dtype(out['chrom_enum'].dtype)
+    assert pd.api.types.is_integer_dtype(out["chrom_enum"].dtype)
 
     # don't convert categorical to enum
-    s.name = 'chrom_string'
-    core.put(f['table'], s, store_categories=False)
-    out = core.get(f['table'])
+    s.name = "chrom_string"
+    core.put(f["table"], s, store_categories=False)
+    out = core.get(f["table"])
     assert len(out.columns) == 6
-    assert not pd.api.types.is_categorical_dtype(out['chrom_string'].dtype)
+    assert not isinstance(out["chrom_string"].dtype, pd.CategoricalDtype)
 
     # scalar input
-    core.put(f['table'], {'foo': 42})
-    out = core.get(f['table'])
+    core.put(f["table"], {"foo": 42})
+    out = core.get(f["table"])
     assert len(out.columns) == 7
-    assert (out['foo'] == 42).all()
+    assert (out["foo"] == 42).all()
 
 
 def test_delete():
-    f = make_hdf5_table('a')
-    core.delete(f['table'])
-    assert len(f['table'].keys()) == 0
+    f = make_hdf5_table("a")
+    core.delete(f["table"])
+    assert len(f["table"].keys()) == 0
 
-    f = make_hdf5_table('a')
-    core.delete(f['table'], ['chrom'])
-    assert len(f['table'].keys()) == 3
+    f = make_hdf5_table("a")
+    core.delete(f["table"], ["chrom"])
+    assert len(f["table"].keys()) == 3
 
-    f = make_hdf5_table('a')
-    core.delete(f['table'], 'chrom')
-    assert len(f['table'].keys()) == 3
+    f = make_hdf5_table("a")
+    core.delete(f["table"], "chrom")
+    assert len(f["table"].keys()) == 3
 
 
 def test_region_to_offset_extent(mock_cooler):
@@ -130,35 +120,29 @@ def test_region_to_offset_extent(mock_cooler):
 
     region = ("chr1", 159, 402)
     first, last = 1, 4
-    assert core.region_to_extent(
-        mock_cooler, chromID_lookup, region, binsize
-    ) == (first, last + 1)
+    assert core.region_to_extent(mock_cooler, chromID_lookup, region, binsize) == (
+        first,
+        last + 1,
+    )
     assert core.region_to_extent(mock_cooler, chromID_lookup, region, None) == (
         first,
         last + 1,
     )
-    assert core.region_to_offset(
-        mock_cooler, chromID_lookup, region, binsize
-    ) == first
-    assert core.region_to_offset(
-        mock_cooler, chromID_lookup, region, None
-    ) == first
+    assert core.region_to_offset(mock_cooler, chromID_lookup, region, binsize) == first
+    assert core.region_to_offset(mock_cooler, chromID_lookup, region, None) == first
 
     region = ("chr1", 159, 400)
     first, last = 1, 3
-    assert core.region_to_extent(
-        mock_cooler, chromID_lookup, region, binsize
-    ) == (first, last + 1)
+    assert core.region_to_extent(mock_cooler, chromID_lookup, region, binsize) == (
+        first,
+        last + 1,
+    )
     assert core.region_to_extent(mock_cooler, chromID_lookup, region, None) == (
         first,
         last + 1,
     )
-    assert core.region_to_offset(
-        mock_cooler, chromID_lookup, region, binsize
-    ) == first
-    assert core.region_to_offset(
-        mock_cooler, chromID_lookup, region, None
-    ) == first
+    assert core.region_to_offset(mock_cooler, chromID_lookup, region, binsize) == first
+    assert core.region_to_offset(mock_cooler, chromID_lookup, region, None) == first
 
 
 def test_interval_ops():
@@ -177,7 +161,6 @@ def test_interval_ops():
 
 
 def test_indexing_mixin():
-
     class Impl(_IndexingMixin):
         def __init__(self, shape):
             self._shape = shape
@@ -192,7 +175,7 @@ def test_indexing_mixin():
 
     # row scalar
     assert obj[5] == (5, 6, 0, 10)
-    assert obj[5, ] == (5, 6, 0, 10)
+    assert obj[5,] == (5, 6, 0, 10)
 
     # row slice
     assert obj[:] == (0, 10, 0, 10)
@@ -253,27 +236,25 @@ def test_selector1d():
     # assert s[10.1] == (10.1, 11.1)  # not casting
     # assert s[nmax+10] == (nmax+10, nmax+11)
 
-
     slicer = lambda fields, lo, hi: pd.DataFrame(  # noqa
-        np.zeros((hi - lo, len(fields))),
-        columns=fields
+        np.zeros((hi - lo, len(fields))), columns=fields
     )
-    fetcher = lambda x: list(map(int, x.split(':')))  # noqa
+    fetcher = lambda x: list(map(int, x.split(":")))  # noqa
     nmax = 50
-    sel = core.RangeSelector1D(['a', 'b', 'c'], slicer, fetcher, nmax)
-    assert sel.columns.tolist() == ['a', 'b', 'c']
-    assert list(sel.keys()) == ['a', 'b', 'c']
+    sel = core.RangeSelector1D(["a", "b", "c"], slicer, fetcher, nmax)
+    assert sel.columns.tolist() == ["a", "b", "c"]
+    assert list(sel.keys()) == ["a", "b", "c"]
     assert isinstance(sel.dtypes, pd.Series)
-    assert 'a' in sel
+    assert "a" in sel
     assert len(sel) == 50
-    assert len(sel[['a', 'b']].columns) == 2
-    assert len(sel[['a']].columns) == 1
+    assert len(sel[["a", "b"]].columns) == 2
+    assert len(sel[["a"]].columns) == 1
     assert np.all(sel[5] == 0)
-    assert np.all(sel[5, ] == 0)
-    assert len(sel.fetch('5:10')) == 5
+    assert np.all(sel[5,] == 0)
+    assert len(sel.fetch("5:10")) == 5
 
     # some things are broken here
-    series_view = sel['a']
+    series_view = sel["a"]
     assert len(series_view) == 50
     assert series_view.shape == (50,)
     # series_view.columns ???
@@ -294,17 +275,16 @@ def test_selector2d():
         s[::2, :]
     assert s.shape == (nmax, nmax)
 
-
-    slicer = lambda field, i0, i1, j0, j1: ( # noqa
+    slicer = lambda field, i0, i1, j0, j1: (  # noqa
         np.zeros((i1 - i0, j1 - j0))
     )
     fetcher = lambda x, y=None: (0, 10, 0, 10)  # noqa
     nmax = 50
-    sel = core.RangeSelector2D('count', slicer, fetcher, (nmax, nmax))
+    sel = core.RangeSelector2D("count", slicer, fetcher, (nmax, nmax))
     assert sel.shape == (50, 50)
     assert len(sel) == 50
     assert sel[:10, 5:10].shape == (10, 5)
-    assert sel.fetch('0:10', '0:10').shape == (10, 10)
+    assert sel.fetch("0:10", "0:10").shape == (10, 10)
 
 
 def test_slice_matrix(mock_cooler):
@@ -330,8 +310,7 @@ def test_slice_matrix(mock_cooler):
         r_fill = r.toarray() + r.toarray().T
 
         reader = core.CSRReader(
-            mock_cooler["pixels"],
-            mock_cooler["indexes"]["bin1_offset"]
+            mock_cooler["pixels"], mock_cooler["indexes"]["bin1_offset"]
         )
 
         # query of data in storage (upper triangle)
@@ -340,7 +319,7 @@ def test_slice_matrix(mock_cooler):
             field="count",
             bbox=(i0, i1, j0, j1),
             chunksize=10,
-            return_index=True
+            return_index=True,
         )
         arr_triu = query.to_array()
         assert np.allclose(r_triu[i0:i1, j0:j1], arr_triu)
@@ -351,7 +330,7 @@ def test_slice_matrix(mock_cooler):
             field="count",
             bbox=(i0, i1, j0, j1),
             chunksize=10,
-            return_index=True
+            return_index=True,
         )
         arr_fill = query.to_array()
         assert np.allclose(r_fill[i0:i1, j0:j1], arr_fill)
