@@ -1,4 +1,5 @@
 # import filecmp
+import importlib.util
 import os
 import os.path as op
 import tempfile
@@ -15,7 +16,9 @@ from cooler.cli.cload import pairs as cload_pairs
 from cooler.cli.cload import tabix as cload_tabix
 from cooler.cli.load import load
 
-_pandas_major_version = int(pd.__version__.split('.')[0])
+pysam_missing = importlib.util.find_spec("pysam") is None
+pairix_missing = importlib.util.find_spec("pypairix") is None
+_pandas_major_version = int(pd.__version__.split(".")[0])
 
 tmp = tempfile.gettempdir()
 testdir = op.realpath(op.dirname(__file__))
@@ -175,25 +178,33 @@ def test_from_hdf5_pairs():
     should_work_with_int32_cols(chromsizes, bintable, mock_pairs)
 
 
+@pytest.mark.skipif(pysam_missing, reason="pysam not installed")
 @pytest.mark.filterwarnings("ignore")
 @pytest.mark.parametrize(
-    "bins_path,pairs_path,ref_path",
+    "bins_path,pairs_path,ref_path,nproc",
     [
         (
             op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
             op.join(testdir, "data", "hg19.GM12878-MboI.pairs.subsample.sorted.txt.gz"),
             op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.cool"),
-        )
+            8,
+        ),
+        (
+            op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
+            op.join(testdir, "data", "hg19.GM12878-MboI.pairs.subsample.sorted.txt.gz"),
+            op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.cool"),
+            1,
+        ),
     ],
 )
-def test_cload_tabix(bins_path, pairs_path, ref_path):
+def test_cload_tabix(bins_path, pairs_path, ref_path, nproc):
     cload_tabix.callback(
         bins_path,
         pairs_path,
         testcool_path,
         metadata=None,
         assembly="hg19",
-        nproc=8,
+        nproc=nproc,
         zero_based=False,
         max_split=2,
     )
@@ -207,26 +218,35 @@ def test_cload_tabix(bins_path, pairs_path, ref_path):
         pass
 
 
+@pytest.mark.skipif(pairix_missing, reason="pairix not installed")
 @pytest.mark.parametrize(
-    "bins_path,pairs_path,ref_path",
+    "bins_path,pairs_path,ref_path,nproc",
     [
         (
             op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
             op.join(testdir, "data", "hg19.GM12878-MboI.pairs.subsample.blksrt.txt.gz"),
             op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.cool"),
-        )
+            8,
+        ),
+        (
+            op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
+            op.join(testdir, "data", "hg19.GM12878-MboI.pairs.subsample.blksrt.txt.gz"),
+            op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.cool"),
+            1,
+        ),
     ],
 )
-def test_cload_pairix(bins_path, pairs_path, ref_path):
+def test_cload_pairix(bins_path, pairs_path, ref_path, nproc):
     cload_pairix.callback(
         bins_path,
         pairs_path,
         testcool_path,
         metadata=None,
         assembly="hg19",
-        nproc=8,
+        nproc=nproc,
         zero_based=False,
         max_split=2,
+        block_char="|",
     )
     with h5py.File(testcool_path, "r") as f1, h5py.File(ref_path, "r") as f2:
         assert np.all(f1["pixels/bin1_id"][:] == f2["pixels/bin1_id"][:])
@@ -238,9 +258,24 @@ def test_cload_pairix(bins_path, pairs_path, ref_path):
         pass
 
 
+@pytest.mark.skipif(pairix_missing, reason="pairix not installed")
+def test_cload_pairix_wrong_block_char():
+    with pytest.raises(ValueError):
+        cload_pairix.callback(
+            op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
+            op.join(testdir, "data", "hg19.GM12878-MboI.pairs.subsample.blksrt.txt.gz"),
+            testcool_path,
+            metadata=None,
+            assembly="hg19",
+            nproc=1,
+            zero_based=False,
+            max_split=2,
+            block_char="?",
+        )
+
+
 @pytest.mark.skipif(
-    _pandas_major_version < 1,
-    reason="hash fix only works with pandas >= 1.0"
+    _pandas_major_version < 1, reason="hash fix only works with pandas >= 1.0"
 )
 @pytest.mark.parametrize(
     "bins_path,pairs_path,ref_path",
@@ -259,24 +294,25 @@ def test_cload_pairix(bins_path, pairs_path, ref_path):
             op.join(testdir, "data", "toy.bins.var.bed"),
             op.join(testdir, "data", "toy_hash.pairs.gz"),
             op.join(testdir, "data", "toy.symm.upper.var.cool"),
-        )
+        ),
     ],
 )
 def test_cload_pairs(bins_path, pairs_path, ref_path):
     kwargs = dict(
         metadata=None,
         assembly="hg19",
-        chunksize=int(15e6),
         zero_based=False,
         comment_char="#",
         input_copy_status="unique",
         no_symmetric_upper=False,
         field=(),
+        chunksize=int(15e6),
+        mergebuf=int(20e6),
+        max_merge=200,
         temp_dir=None,
         no_delete_temp=False,
         storage_options=None,
         no_count=False,
-        max_merge=200,
         chrom1=2,
         pos1=3,
         chrom2=4,
@@ -307,16 +343,17 @@ def test_cload_field(bins_path, pairs_path):
     kwargs = dict(
         metadata=None,
         assembly="toy",
-        chunksize=10,
         zero_based=False,
         comment_char="#",
         input_copy_status="unique",
         no_symmetric_upper=False,
+        chunksize=10,
+        mergebuf=10,
+        max_merge=200,
         temp_dir=None,
         no_delete_temp=False,
         storage_options=None,
         no_count=True,
-        max_merge=200,
         chrom1=2,
         pos1=3,
         chrom2=4,
@@ -348,17 +385,18 @@ def test_cload_custom_tempdir(bins_path, pairs_path):
             testcool_path,
             metadata=None,
             assembly="toy",
-            chunksize=10,
             zero_based=False,
             comment_char="#",
             input_copy_status="unique",
             no_symmetric_upper=False,
             field=(),
+            chunksize=10,
+            mergebuf=10,
             temp_dir=temp_dir,
             no_delete_temp=False,
+            max_merge=200,
             storage_options=None,
             no_count=True,
-            max_merge=200,
             chrom1=2,
             pos1=3,
             chrom2=4,
@@ -376,6 +414,8 @@ def test_load_bg2_vs_coo():
         metadata=None,
         assembly="hg19",
         chunksize=int(20e6),
+        mergebuf=int(15e6),
+        max_merge=200,
         field=(),
         count_as_float=False,
         one_based=False,
@@ -396,18 +436,17 @@ def test_load_bg2_vs_coo():
         op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.bg2.gz"),
         out_path1,
         format="bg2",
-        **kwargs
+        **kwargs,
     )
     load.callback(
         op.join(testdir, "data", "hg19.bins.2000kb.bed.gz"),
         op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.coo.txt"),
         out_path2,
         format="coo",
-        **kwargs
+        **kwargs,
     )
 
     with h5py.File(out_path1, "r") as f1, h5py.File(out_path2, "r") as f2:
-
         for col in ["bin1_id", "bin2_id", "count"]:
             assert np.all(f1["pixels"][col][:] == f2["pixels"][col][:])
 
@@ -424,6 +463,8 @@ def test_load_zero_one_based_bg2():
         metadata=None,
         assembly="toy",
         chunksize=10,
+        mergebuf=10,
+        max_merge=200,
         field=(),
         count_as_float=False,
         comment_char="#",
@@ -473,6 +514,8 @@ def test_load_zero_one_based_coo():
         metadata=None,
         assembly="toy",
         chunksize=10,
+        mergebuf=10,
+        max_merge=200,
         field=(),
         count_as_float=False,
         comment_char="#",
@@ -532,6 +575,7 @@ def test_cload_append_mode():
             metadata=None,
             assembly="hg19",
             chunksize=int(15e6),
+            mergebuf=int(15e6),
             zero_based=False,
             comment_char="#",
             input_copy_status="unique",
@@ -552,7 +596,7 @@ def test_cload_append_mode():
             op.join(testdir, "data", "toy.bins.var.bed"),
             op.join(testdir, "data", "toy.pairs"),
             out_path,
-            **kwargs
+            **kwargs,
         )
         with h5py.File(out_path, "r") as f:
             if append:
@@ -574,6 +618,8 @@ def test_load_append_mode():
             metadata=None,
             assembly="hg19",
             chunksize=int(20e6),
+            mergebuf=int(20e6),
+            max_merge=200,
             field=(),
             count_as_float=False,
             one_based=False,
@@ -590,7 +636,7 @@ def test_load_append_mode():
             op.join(testdir, "data", "hg19.GM12878-MboI.matrix.2000kb.coo.txt"),
             out_path,
             format="coo",
-            **kwargs
+            **kwargs,
         )
         with h5py.File(out_path, "r") as f:
             if append:
@@ -613,6 +659,8 @@ def test_load_custom_tempdir():
             metadata=None,
             assembly="hg19",
             chunksize=int(20e6),
+            mergebuf=int(20e6),
+            max_merge=200,
             field=(),
             count_as_float=False,
             one_based=False,
@@ -623,7 +671,6 @@ def test_load_custom_tempdir():
             no_delete_temp=False,
             storage_options=None,
             append=False,
-
         )
         pixels = cooler.Cooler(testcool_path).pixels()[:]
         assert "count" in pixels.columns and types.is_integer_dtype(
